from nba_api.stats.endpoints._base import Endpoint
from nba_api.stats.library.http import NBAStatsHTTP
from nba_api.stats.library.parameters import (
    LastNGames,
    MeasureTypeDetailedDefense,
    Month,
    PaceAdjust,
    PerModeDetailed,
    Period,
    PlusMinus,
    Rank,
    Season,
    SeasonType,
    ConferenceNullable,
    DivisionSimpleNullable,
    GameSegmentNullable,
    LeagueIDNullable,
    LocationNullable,
    OutcomeNullable,
    SeasonSegmentNullable,
    ShotClockRangeNullable,
    DivisionNullable,
)


class TeamAndPlayersVsPlayers(Endpoint):
    endpoint = "teamandplayersvsplayers"
    expected_data = {
        "PlayersVsPlayers": [
            "GROUP_SET",
            "TITLE_DESCRIPTION",
            "DESCRIPTION",
            "MIN",
            "FGM",
            "FGA",
            "FG_PCT",
            "FG3M",
            "FG3A",
            "FG3_PCT",
            "FTM",
            "FTA",
            "FT_PCT",
            "OREB",
            "DREB",
            "REB",
            "AST",
            "TOV",
            "STL",
            "BLK",
            "BLKA",
            "PF",
            "PFD",
            "PTS",
            "PLUS_MINUS",
        ],
        "TeamPlayersVsPlayersOff": [
            "GROUP_SET",
            "TITLE_DESCRIPTION",
            "PLAYER_ID",
            "PLAYER_NAME",
            "MIN",
            "FGM",
            "FGA",
            "FG_PCT",
            "FG3M",
            "FG3A",
            "FG3_PCT",
            "FTM",
            "FTA",
            "FT_PCT",
            "OREB",
            "DREB",
            "REB",
            "AST",
            "TOV",
            "STL",
            "BLK",
            "BLKA",
            "PF",
            "PFD",
            "PTS",
            "PLUS_MINUS",
        ],
        "TeamPlayersVsPlayersOn": [
            "GROUP_SET",
            "TITLE_DESCRIPTION",
            "PLAYER_ID",
            "PLAYER_NAME",
            "MIN",
            "FGM",
            "FGA",
            "FG_PCT",
            "FG3M",
            "FG3A",
            "FG3_PCT",
            "FTM",
            "FTA",
            "FT_PCT",
            "OREB",
            "DREB",
            "REB",
            "AST",
            "TOV",
            "STL",
            "BLK",
            "BLKA",
            "PF",
            "PFD",
            "PTS",
            "PLUS_MINUS",
        ],
        "TeamVsPlayers": [
            "GROUP_SET",
            "TITLE_DESCRIPTION",
            "DESCRIPTION",
            "MIN",
            "FGM",
            "FGA",
            "FG_PCT",
            "FG3M",
            "FG3A",
            "FG3_PCT",
            "FTM",
            "FTA",
            "FT_PCT",
            "OREB",
            "DREB",
            "REB",
            "AST",
            "TOV",
            "STL",
            "BLK",
            "BLKA",
            "PF",
            "PFD",
            "PTS",
            "PLUS_MINUS",
        ],
        "TeamVsPlayersOff": [
            "GROUP_SET",
            "TITLE_DESCRIPTION",
            "DESCRIPTION",
            "MIN",
            "FGM",
            "FGA",
            "FG_PCT",
            "FG3M",
            "FG3A",
            "FG3_PCT",
            "FTM",
            "FTA",
            "FT_PCT",
            "OREB",
            "DREB",
            "REB",
            "AST",
            "TOV",
            "STL",
            "BLK",
            "BLKA",
            "PF",
            "PFD",
            "PTS",
            "PLUS_MINUS",
        ],
    }

    nba_response = None
    data_sets = None
    player_stats = None
    team_stats = None
    headers = None

    def __init__(
        self,
        vs_team_id,
        vs_player_id5,
        vs_player_id4,
        vs_player_id3,
        vs_player_id2,
        vs_player_id1,
        team_id,
        player_id5,
        player_id4,
        player_id3,
        player_id2,
        player_id1,
        last_n_games=LastNGames.default,
        measure_type_detailed_defense=MeasureTypeDetailedDefense.default,
        month=Month.default,
        opponent_team_id=0,
        pace_adjust=PaceAdjust.default,
        per_mode_detailed=PerModeDetailed.default,
        period=Period.default,
        plus_minus=PlusMinus.default,
        rank=Rank.default,
        season=Season.default,
        season_type_playoffs=SeasonType.default,
        conference_nullable=ConferenceNullable.default,
        date_from_nullable="",
        date_to_nullable="",
        division_simple_nullable=DivisionSimpleNullable.default,
        game_segment_nullable=GameSegmentNullable.default,
        league_id_nullable=LeagueIDNullable.default,
        location_nullable=LocationNullable.default,
        outcome_nullable=OutcomeNullable.default,
        season_segment_nullable=SeasonSegmentNullable.default,
        shot_clock_range_nullable=ShotClockRangeNullable.default,
        vs_conference_nullable=ConferenceNullable.default,
        vs_division_nullable=DivisionNullable.default,
        proxy=None,
        headers=None,
        timeout=30,
        get_request=True,
    ):
        self.proxy = proxy
        if headers is not None:
            self.headers = headers
        self.timeout = timeout
        self.parameters = {
            "VsTeamID": vs_team_id,
            "VsPlayerID5": vs_player_id5,
            "VsPlayerID4": vs_player_id4,
            "VsPlayerID3": vs_player_id3,
            "VsPlayerID2": vs_player_id2,
            "VsPlayerID1": vs_player_id1,
            "TeamID": team_id,
            "PlayerID5": player_id5,
            "PlayerID4": player_id4,
            "PlayerID3": player_id3,
            "PlayerID2": player_id2,
            "PlayerID1": player_id1,
            "LastNGames": last_n_games,
            "MeasureType": measure_type_detailed_defense,
            "Month": month,
            "OpponentTeamID": opponent_team_id,
            "PaceAdjust": pace_adjust,
            "PerMode": per_mode_detailed,
            "Period": period,
            "PlusMinus": plus_minus,
            "Rank": rank,
            "Season": season,
            "SeasonType": season_type_playoffs,
            "Conference": conference_nullable,
            "DateFrom": date_from_nullable,
            "DateTo": date_to_nullable,
            "Division": division_simple_nullable,
            "GameSegment": game_segment_nullable,
            "LeagueID": league_id_nullable,
            "Location": location_nullable,
            "Outcome": outcome_nullable,
            "SeasonSegment": season_segment_nullable,
            "ShotClockRange": shot_clock_range_nullable,
            "VsConference": vs_conference_nullable,
            "VsDivision": vs_division_nullable,
        }
        if get_request:
            self.get_request()

    def get_request(self):
        self.nba_response = NBAStatsHTTP().send_api_request(
            endpoint=self.endpoint,
            parameters=self.parameters,
            proxy=self.proxy,
            headers=self.headers,
            timeout=self.timeout,
        )
        self.load_response()

    def load_response(self):
        data_sets = self.nba_response.get_data_sets()
        self.data_sets = [
            Endpoint.DataSet(data=data_set)
            for data_set_name, data_set in data_sets.items()
        ]
        self.players_vs_players = Endpoint.DataSet(data=data_sets["PlayersVsPlayers"])
        self.team_players_vs_players_off = Endpoint.DataSet(
            data=data_sets["TeamPlayersVsPlayersOff"]
        )
        self.team_players_vs_players_on = Endpoint.DataSet(
            data=data_sets["TeamPlayersVsPlayersOn"]
        )
        self.team_vs_players = Endpoint.DataSet(data=data_sets["TeamVsPlayers"])
        self.team_vs_players_off = Endpoint.DataSet(data=data_sets["TeamVsPlayersOff"])
